.tipster_controls {
        font-size: 75%;
        padding-bottom: 5px;
        padding-right: 5px;
        text-align: right;
}

.tipster_content {
        padding-top: 10px;
        padding-bottom: 10px;
        padding-left: 5px;
}
